==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/SiteNetworkAccessType.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;
/**
 * Represents the implementation of siteNetworkAccessType.
 */
public abstract class SiteNetworkAccessType {

    /**
     * Returns the attribute site-network-access-type.
     *
     * @return site-network-access-type value of site-network-access-type
     */
    public static String siteNetworkAccessTypeToString() {
        return "site-network-access-type";
    }

    /**
     * Returns the object of siteNetworkAccessType fromString input String siteNetworkAccessType.
     *
     * @param valInString value of input String
     * @return siteNetworkAccessType
     */
    public static Class fromString(String valInString) {
        if (valInString.equals("site-network-access-type")) {
            return SiteNetworkAccessType.class;
        }
        throw new IllegalArgumentException("not a valid input element");
    }
}

==> onos-yang-runtime-2.4-sources.jar: org/onosproject/yang/gen/v1/ietfl3vpnsvc/rev20160730/ietfl3vpnsvc/SiteNetworkAccessType.java <==
/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.ietfl3vpnsvc.rev20160730.ietfl3vpnsvc;

/**
 * Represents the implementation of siteNetworkAccessType.
 */
public abstract class SiteNetworkAccessType {

    /**
     * Returns the attribute site-network-access-type.
     *
     * @return site-network-access-type value of site-network-access-type
     */
    public static String siteNetworkAccessTypeToString() {
        return "site-network-access-type";
    }

    /**
     * Returns the object of siteNetworkAccessType fromString input String siteNetworkAccessType.
     *
     * @param valInString value of input String
     * @return siteNetworkAccessType
     */
    public static Class fromString(String valInString) {
        if (valInString.equals("site-network-access-type")) {
            return SiteNetworkAccessType.class;
        } else if (valInString.equals("point-to-point")) {
            return PointToPoint.class;
        } else if (valInString.equals("multipoint")) {
            return Multipoint.class;
        }
        throw new IllegalArgumentException("not a valid input element");
    }
}
